.. highlight:: shell

============
Credits
============


This package would not have been possible without the amazing job done by the AWS CloudFormation team!

This package would not have been possible without the amazing community around `Troposphere`_!

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
.. _Troposphere: https://github.com/cloudtools/troposphere
